@@ -107,8 +107,6 @@ typedef struct
 
 /* DELIVERY ADDRESSING PROPERTIES */
 
-#if 0
-/* NOT USED */
 typedef struct
 {
 	CardProperty prop;
@@ -124,21 +122,6 @@ typedef struct
 	int type;
 	char *data;
 } CardDelLabel;
-#else
-/* new ones I'm using */
-typedef struct
-{
-    CardProperty prop;
-
-    gint type;
-    gchar *street1;
-    gchar *street2;
-    gchar *city;
-    gchar *state;
-    gchar *country;
-    gchar *zip;
-} CardPostAddr;
-#endif
 
 /* TELECOMMUNICATIONS ADDRESSING PROPERTIES */
 
@@ -151,8 +134,6 @@ typedef struct
 	char *data;
 } CardPhone;
 
-/* NOT USED - We're not keeping a list of emails, just one per person */
-#if 0
 typedef struct 
 {
 	CardProperty prop;
@@ -160,15 +141,6 @@ typedef struct
 	enum EMailType type;
 	char *data;
 } CardEMail;
-#else
-typedef struct 
-{
-	CardProperty prop;
-	
-	enum EMailType type;
-	char *address;
-} CardEMail;
-#endif
 
 typedef struct
 {
@@ -240,14 +212,10 @@ typedef struct _Card
 	CardPhoto       photo;
 	CardBDay        bday;
 
-/* NOT USED
         CardList        deladdr;
 	CardList        dellabel;
-*/
-        CardList        postal;
-	
 	CardList        phone;
-	CardEMail       email;
+	CardList        email;
 	CardStrProperty mailer;
 	
 	CardTimeZone    timezn;
@@ -270,16 +238,17 @@ typedef struct _Card
 	int flag;
 } Card;
 
-Card         *card_new(void);
-void          card_free(Card *crd);
-void          card_prop_free(CardProperty prop);
-CardProperty  empty_CardProperty(void);
-GList        *card_load (GList *crdlist, char *fname);
-void          card_save(Card *crd, FILE *fp);
-char         *card_to_string (Card *card);
+extern Card         *card_new (void);
+extern void          card_free (Card *crd);
+extern void          card_prop_free (CardProperty prop);
+extern CardProperty  card_prop_empty (void);
+extern int           card_check_prop (CardProperty prop);
+extern GList        *card_load (GList *crdlist, char *fname);
+extern void          card_save (Card *crd, FILE *fp);
+extern char         *card_to_string (Card *card);
 
-char *card_bday_str(CardBDay bday);
-char *card_timezn_str(CardTimeZone timezn);
-char *card_geopos_str(CardGeoPos geopos);
+extern char *card_bday_str (CardBDay bday);
+extern char *card_timezn_str (CardTimeZone timezn);
+extern char *card_geopos_str (CardGeoPos geopos);
 
 #endif
