@@ -32,7 +32,7 @@
 #include "my.h"
 #include "sort.h"
 #include "list.h"
-#include "addresslist.h"
+#include "deladdrlist.h"
 #include "phonelist.h"
 #include "world.xpm"
 #include "misc.h"
@@ -52,42 +52,6 @@ typedef struct
 	GtkWidget *entry, *sens, *back;
 } GnomeCardFind;
 
-/* NOT USED
-typedef struct
-{
-	GtkWidget *def_phone, *def_email;
-} GnomeCardSetup;
-
-typedef struct
-{
-	GtkWidget *data, *type;
-	
-	GList *l;
-} GnomeCardEMail;
-
-typedef struct
-{
-	GtkWidget *type[13], *data;
-	
-	GList *l;
-} GnomeCardPhone;
-
-
-typedef struct
-{
-	GtkWidget *type[6], *data[7];
-	
-	GList *l;
-} GnomeCardDelAddr;
-
-typedef struct
-{
-	GtkWidget *type[6], *data;
-	
-	GList *l;
-} GnomeCardDelLabel;
-*/
-
 static void gnomecard_prop_close(GtkWidget *widget, gpointer node);
 static void gnomecard_take_from_name(GtkWidget *widget, gpointer data);
 static void gnomecard_cancel(GtkWidget *widget, gpointer data);
@@ -96,12 +60,6 @@ static void gnomecard_find_card(GtkWidget *w, gpointer data);
 static void gnomecard_save_call(GtkWidget *widget, gpointer data);
 static int gnomecard_match_pattern(char *pattern, char *str, int sens);
 
-gchar *email_type_name[] = 
-                 { N_("America On-Line"), N_("Apple Link"), N_("AT&T"),
-		               N_("CIS"), N_("e-World"), N_("Internet"), N_("IBM"),
-		               N_("MCI"), N_("Power Share"), N_("Prodigy"), N_("TLX"),
-		               N_("X400"), NULL };
-
 /* handle when the user applies changes to the card editor propertybox */
 static void gnomecard_prop_apply(GtkWidget *widget, int page)
 {
@@ -131,14 +89,13 @@ static void gnomecard_prop_apply(GtkWidget *widget, int page)
 	crd->name.prefix     = MY_STRDUP(gtk_entry_get_text(GTK_ENTRY(ce->pre)));
 	crd->name.suffix     = MY_STRDUP(gtk_entry_get_text(GTK_ENTRY(ce->suf)));
 
-/* NOT USED (yet)	
 	tt = gnome_date_edit_get_date(GNOME_DATE_EDIT(ce->bday)); 
 	tm = localtime(&tt);
 	
 	crd->bday.year       = tm->tm_year + 1900;
 	crd->bday.month      = tm->tm_mon + 1;
 	crd->bday.day        = tm->tm_mday;
-*/
+	
 	crd->timezn.sign  = (ce->tzh < 0)? -1: 1;
 	crd->timezn.hours = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(ce->tzh));
 	crd->timezn.mins  = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(ce->tzm));
@@ -173,35 +130,72 @@ static void gnomecard_prop_apply(GtkWidget *widget, int page)
 	MY_FREE(crd->categories.str);
 	MY_FREE(crd->comment.str);
 	MY_FREE(crd->url.str);
-	MY_FREE(crd->email.address);
 	
 	crd->categories.str = MY_STRDUP(gtk_entry_get_text(GTK_ENTRY(ce->categories)));
 	crd->comment.str = gtk_editable_get_chars(GTK_EDITABLE(ce->comment), 
 			 0, gtk_text_get_length(GTK_TEXT(ce->comment)));
-	crd->url.str     = MY_STRDUP(gtk_entry_get_text(GTK_ENTRY(ce->url)));
-	crd->email.address   = MY_STRDUP(gtk_entry_get_text(GTK_ENTRY(ce->email)));
+	crd->url.str     = MY_STRDUP(gtk_entry_get_text
+				     (GTK_ENTRY(ce->emaillist->url)));
 
-	/* postal addresses */
-	/* store results from current displayed address type, since */
-	/* we may not have stored changes yet                       */
-	copyGUIToCurAddr(ce);
+	/* email list */
+	/* remove old email list */
+	{
+		CardEMail *email;
+		GList *node_tmp;
+		
+		for (node = crd->email.l; node; node = node_tmp) {
+			node_tmp = node->next;
+			email = (CardEMail *) node->data;
+			g_free (email->data);
+			g_free (email);
+			g_list_free_1 (node);
+		}
+	}
 
-	/* remove old address list */
-	deleteAddrList(&crd->postal);
+	/* link to new email list */
+	crd->email.l = emaillist_get_entries (ce->emaillist);
+	
+	
+	/* delivery addresses */
+	/* remove old delivery addresses list */
+	{
+		CardDelAddr *deladdr;
+		GList *node_tmp;
+		int i;
+		
+		for (node = crd->deladdr.l; node; node = node_tmp) {
+			node_tmp = node->next;
+			deladdr = (CardDelAddr *) node->data;
+			
+			for (i = 0; i < DELADDR_MAX; i++)
+			  g_free (deladdr->data[i]);
+			
+			g_free (deladdr);
+			g_list_free_1 (node);
+		}
+	}
 
 	/* link to new address list */
-	copyAddrList(ce->postal, &crd->postal);
+	crd->deladdr.l = deladdrlist_get_entries (ce->deladdrlist);
 
+	
 	/* phone numbers */
-	/* store results from current displayed phone type, since */
-	/* we may not have stored changes yet                     */
-	copyGUIToCurPhone(ce);
-
 	/* remove old phone list */
-	deletePhoneList(&crd->phone);
+	{
+		CardPhone *phone;
+		GList *node_tmp;
+		
+		for (node = crd->phone.l; node; node = node_tmp) {
+			node_tmp = node->next;
+			phone = (CardPhone *) node->data;
+			g_free (phone->data);
+			g_free (phone);
+			g_list_free_1 (node);
+		}
+	}
 
 	/* link to new phone list */
-	copyPhoneList(ce->phone, &crd->phone);
+	crd->phone.l = phonelist_get_entries (ce->phonelist);
 
 	/* key data */
         MY_FREE(crd->key.data);
@@ -239,8 +233,8 @@ static void gnomecard_prop_close(GtkWidget *widget, gpointer data)
 
     /* cleanup */
     ce = (GnomeCardEditor *) gtk_object_get_user_data(GTK_OBJECT(widget));
-    deleteAddrList(&ce->postal);
-    deletePhoneList(&ce->phone);
+    deladdrlist_del_entries (ce->deladdrlist);
+    phonelist_del_entries (ce->phonelist);
 
     card = (Card *) data;
     card->flag = FALSE;
@@ -282,11 +276,8 @@ extern void gnomecard_edit(GList *node)
 	GtkWidget *radio1, *radio2, *button;
 	GtkObject *adj;
 	GtkWidget *nametable;
-	GSList    *addrtypegroup=NULL;
-	GSList    *phonetypegroup=NULL;
 	Card *crd;
 	time_t tmp_time;
-	gint i;
 
 	help_entry.name = gnome_app_id;
 
@@ -390,8 +381,8 @@ extern void gnomecard_edit(GList *node)
 	gtk_table_attach(GTK_TABLE(nametable), label, 0, 1, 2, 3,
 			 GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 0, 0);
 	gtk_table_attach(GTK_TABLE(nametable), align, 1, 2, 2, 3, 
-			 GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL,
-			 GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+			 GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 
+			 GNOME_PAD_SMALL, 0);
 
 	label = gtk_label_new(_("Suffix:"));
 	ce->suf = entry = my_gtk_entry_new(5, crd->name.suffix);
@@ -402,7 +393,7 @@ extern void gnomecard_edit(GList *node)
 			 GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 0, 0);
 	gtk_table_attach(GTK_TABLE(nametable), align, 3, 4, 2, 3, 
 			 GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL,
-			 GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+			 GNOME_PAD_SMALL, 0);
 
 	/* organization and internet info share same line */
 	/* add organization to identity notetab */
@@ -436,49 +427,31 @@ extern void gnomecard_edit(GList *node)
 			 GTK_FILL | GTK_SHRINK | GTK_EXPAND, GTK_FILL | GTK_SHRINK, 
 			 GNOME_PAD_SMALL, GNOME_PAD_SMALL);
 
+	/* email page */
+        ce->emaillist = emaillist_create_edit_page(crd, box);
+	label = gtk_label_new(_("Network"));
+	gtk_notebook_append_page(GTK_NOTEBOOK(box->notebook), 
+				 ce->emaillist->the_vbox, label);
 
-	/* internet related information */
-	frame = gtk_frame_new(_("Internet Info"));
-	gtk_box_pack_start(GTK_BOX(hbox2), frame, TRUE, TRUE, 0);
-
-	table = my_gtk_table_new(2, 2);
-	gtk_container_add(GTK_CONTAINER(frame), table);
-
-	label = gtk_label_new(_("Email Address:"));
-	gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);
-	ce->email = entry = my_gtk_entry_new(0, crd->email.address);
-	my_connect(entry, "changed", box, &crd->email.prop, PROP_ORG);
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,
-			 GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 
-			 0, 0);
-	gtk_table_attach(GTK_TABLE(table), entry, 1, 2, 0, 1,
-			 GTK_FILL | GTK_SHRINK | GTK_EXPAND, GTK_FILL | GTK_SHRINK,
-			 GNOME_PAD_SMALL, GNOME_PAD_SMALL);
-
-	label = gtk_label_new(_("Homepage URL:"));
-	ce->url = entry = my_gtk_entry_new(0, crd->url.str);
-	my_connect(entry, "changed", box, &crd->url.prop, PROP_URL);
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,
-			 GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 
-			 0, 0);
-	gtk_table_attach(GTK_TABLE(table), entry, 1, 2, 1, 2,
-			 GTK_FILL | GTK_SHRINK | GTK_EXPAND, GTK_FILL | GTK_SHRINK, 
-			 GNOME_PAD_SMALL, GNOME_PAD_SMALL);
-
-	/* add address notetab */
-	hbox = gnomecard_create_address_page(crd, ce, box);
+	/* delivery address page */
+	ce->deladdrlist = deladdrlist_create_edit_page(crd, box);
 	label = gtk_label_new(_("Addresses"));
-	gtk_notebook_append_page(GTK_NOTEBOOK(box->notebook), hbox, label);
+	gtk_notebook_append_page(GTK_NOTEBOOK(box->notebook), 
+				 ce->deladdrlist->the_vbox, label);
 
 	/* phone number page */
-	hbox = gnomecard_create_phone_page(crd, ce, box);
+        ce->phonelist = phonelist_create_edit_page(crd, box);
 	label = gtk_label_new(_("Phone"));
-	gtk_notebook_append_page(GTK_NOTEBOOK(box->notebook), hbox, label);
+	gtk_notebook_append_page(GTK_NOTEBOOK(box->notebook), 
+				 ce->phonelist->the_vbox, label);
 
+	/* Birth date */
 	
-
-/* LOSE BIRTHDAY FOR NOW	
+	vbox = my_gtk_vbox_new();
+	gtk_box_pack_start(GTK_BOX(hbox2), vbox, FALSE, FALSE, 0);
 	hbox = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
+	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
+	
 	label = gtk_label_new(_("Birthdate:"));
 	
 	if (crd->bday.prop.used) {
@@ -499,8 +472,6 @@ extern void gnomecard_edit(GList *node)
 		   box, &crd->bday.prop, PROP_BDAY);
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), entry, FALSE, FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
-*/
 
 	/* Geographical */
 	align2 = gtk_alignment_new(0.5, 0.5, 0, 0);
@@ -603,10 +574,10 @@ extern void gnomecard_edit(GList *node)
 
 	hbox = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, GNOME_PAD);
-	label = gtk_label_new(_("Last Revision:"));
+/*	label = gtk_label_new(_("Last Revision:"));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	label = gtk_label_new(_("The last revision goes here."));
-	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);*/
 	
 	/* Security */
 	
@@ -815,7 +786,7 @@ colsetup_uppress(GtkWidget *widget, gpointer data)
     edit = (ColumnHdrEditor *)data;
     if (GTK_CLIST(edit->destList)->selection) {
 	gint row;
-	GList *l, *m;
+	GList *l;
 	GList *prevnode, *curnode;
 
 	row = GPOINTER_TO_INT(GTK_CLIST(edit->destList)->selection->data);
@@ -864,7 +835,7 @@ colsetup_dnpress(GtkWidget *widget, gpointer data)
     edit = (ColumnHdrEditor *)data;
     if (GTK_CLIST(edit->destList)->selection) {
 	gint row;
-	GList *l, *m;
+	GList *l;
 	GList *curnode, *nextnode;
 
 	row = GPOINTER_TO_INT(GTK_CLIST(edit->destList)->selection->data);
@@ -911,7 +882,7 @@ gnomecard_setup(GtkWidget *widget, gpointer data)
 {
         static GnomeHelpMenuEntry help_entry = { NULL, "properties" };
 	GtkWidget *vbox, *vbox2, *frame;
-	GtkWidget *label, *check;
+	GtkWidget *label;
 
 	GtkWidget *table;
 	GtkWidget *scrollwin;
@@ -1044,350 +1015,6 @@ gnomecard_setup(GtkWidget *widget, gpointer data)
 	gtk_widget_show_all(GTK_WIDGET(edit->box));
 }
 
-#if 0
-/* NOT USED */
-void gnomecard_add_email(GtkWidget *widget, gpointer data)
-{
-	GnomeCardEMail *e;
-	CardEMail *email;
-	char *text;
-
-	g_message("gnomecard_add_email not used/implemented");
-#if 0	
-	e = (GnomeCardEMail *) data;
-	
-	text = gtk_entry_get_text(GTK_ENTRY(e->data));
-	if (*text == 0)
-		return;
-	
-	email = g_malloc(sizeof(CardEMail));
-	email->data = g_strdup(text);
-	email->prop = empty_CardProperty();
-	email->prop.used = TRUE;
-	email->prop.type = PROP_EMAIL;
-	email->type = (int) gtk_object_get_user_data(GTK_OBJECT(gtk_menu_get_active(GTK_MENU(e->type))));
-	
-	((Card *) e->l->data)->email.l = g_list_append(((Card *) e->l->data)->email.l, email);
-
-	gnomecard_update_list(e->l->data);
-	
-	gtk_editable_delete_text(GTK_EDITABLE(e->data), 0, strlen(text));
-	gnomecard_set_changed(TRUE);
-#endif
-}
-
-extern void gnomecard_add_email_call(GtkWidget *widget, gpointer data)
-{
-	GtkWidget *w, *hbox, *label, *omenu, *item;
-	GnomeCardEMail *e;
-	char *title;
-	Card *crd;
-	int i;
-
-	g_message("gnomecard_add_email_call not used/implemented");
-#if 0	
-	crd = gnomecard_curr_crd->data;
-
-	/* + 7 for case crd->fname == 0, which sprintf's to "(null)" */
-	title = g_malloc(strlen(_("Add E-mail for ")) + MY_STRLEN(crd->fname.str) + 7);
-	
-	sprintf(title, _("Add E-mail for %s"), crd->fname.str);
-	
-	e = g_malloc(sizeof(GnomeCardEMail));
-	e->l = gnomecard_curr_crd;
-	w = gnome_dialog_new(title, "Add", GNOME_STOCK_BUTTON_CLOSE, NULL);
-	gtk_object_set_user_data(GTK_OBJECT(w), e);
-	gnome_dialog_button_connect(GNOME_DIALOG(w), 0,
-															GTK_SIGNAL_FUNC(gnomecard_add_email),	e);
-	gnome_dialog_button_connect_object(GNOME_DIALOG(w),	1,
-																		 GTK_SIGNAL_FUNC(gnomecard_cancel),
-																		 GTK_OBJECT(w));
-
-	e->data = my_hbox_entry(GNOME_DIALOG(w)->vbox, "E-mail address:", NULL);
-
-	hbox = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
-	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(w)->vbox), hbox, FALSE, FALSE, 0);
-	label = gtk_label_new(_("E-mail type:"));
-	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	omenu = gtk_option_menu_new();
-	gtk_box_pack_start(GTK_BOX(hbox), omenu, FALSE, FALSE, 0);
-	
-	e->type = gtk_menu_new();
-	
-	for (i = 0; email_type_name[i]; i++) {
-		item = gtk_menu_item_new_with_label(email_type_name[i]);
-		gtk_object_set_user_data(GTK_OBJECT(item), (gpointer) i);
-		gtk_menu_append(GTK_MENU(e->type), item);
-		gtk_widget_show(item);
-	}
-	
-	gtk_menu_set_active(GTK_MENU(e->type), EMAIL_INET);
-	gtk_option_menu_set_menu(GTK_OPTION_MENU(omenu), e->type);
-	
-	gtk_widget_show_all(GNOME_DIALOG(w)->vbox);
-	gtk_widget_show(w);
-#endif
-}
-
-
-void gnomecard_add_phone(GtkWidget *widget, gpointer data)
-{
-	GnomeCardPhone *p;
-	CardPhone *phone;
-	char *text;
-	int i;
-	
-	p = (GnomeCardPhone *) data;
-	
-	text = gtk_entry_get_text(GTK_ENTRY(p->data));
-	if (*text == 0)
-		return;
-	
-	phone = g_malloc(sizeof(CardPhone));
-	phone->data = g_strdup(text);
-	phone->prop = empty_CardProperty();
-	phone->prop.used = TRUE;
-	phone->type = 0;
-	for (i = 0; i < 13; i++)
-		if (GTK_TOGGLE_BUTTON(p->type[i])->active)
-			phone->type |= (int) gtk_object_get_user_data(GTK_OBJECT(p->type[i]));
-	
-	((Card *) p->l->data)->phone.l = g_list_append(((Card *) p->l->data)->phone.l, phone);
-
-	gnomecard_update_list(p->l->data);
-	
-	gtk_editable_delete_text(GTK_EDITABLE(p->data), 0, strlen(text));
-	gnomecard_set_changed(TRUE);
-}
-
-extern void gnomecard_add_phone_call(GtkWidget *widget, gpointer data)
-{
-	GtkWidget *w, *hbox, *frame, *vbox;
-	GnomeCardPhone *p;
-	char *title;
-	Card *crd;
-	int i;
-	
-	crd = gnomecard_curr_crd->data;
-	
-	/* + 7 for case crd->fname == 0, which sprintf's to "(null)" */
-	title = g_malloc(strlen(_("Add Telephone Number for ")) + MY_STRLEN(crd->fname.str) + 7);
-	
-	sprintf(title, _("Add Telephone Number for %s"), crd->fname.str);
-	
-	p = g_malloc(sizeof(GnomeCardPhone));
-	p->l = gnomecard_curr_crd;
-	w = gnome_dialog_new(title, "Add", GNOME_STOCK_BUTTON_CLOSE, NULL);
-	gtk_object_set_user_data(GTK_OBJECT(w), p);
-	gnome_dialog_button_connect(GNOME_DIALOG(w), 0,
-															GTK_SIGNAL_FUNC(gnomecard_add_phone),	p);
-	gnome_dialog_button_connect_object(GNOME_DIALOG(w),	1,
-																		 GTK_SIGNAL_FUNC(gnomecard_cancel),
-																		 GTK_OBJECT(w));
-
-	p->data = my_hbox_entry(GNOME_DIALOG(w)->vbox, "Telephone Number:", NULL);
-	
-	frame = gtk_frame_new(_("Phone type:"));
-	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(w)->vbox), frame, FALSE, FALSE, 0);
-	hbox = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
-	gtk_container_add(GTK_CONTAINER(frame), hbox);
-	
-	vbox = gtk_vbox_new(FALSE, GNOME_PAD_SMALL);
-	gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 0);
-
-	for (i = 0; i < 7; i++) {
-		p->type[i] = gtk_check_button_new_with_label(phone_type_name[i]);
-		gtk_object_set_user_data(GTK_OBJECT(p->type[i]), (gpointer) (1 << i));
-		gtk_box_pack_start(GTK_BOX(vbox), p->type[i], FALSE, FALSE, 0);
-	}
-		
-	vbox = gtk_vbox_new(FALSE, GNOME_PAD_SMALL);
-	gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 0);
-
-	for (i = 7; i < 13; i++) {
-		p->type[i] = gtk_check_button_new_with_label(phone_type_name[i]);
-		gtk_object_set_user_data(GTK_OBJECT(p->type[i]), (gpointer) (1 << i));
-		gtk_box_pack_start(GTK_BOX(vbox), p->type[i], FALSE, FALSE, 0);
-	}
-	
-	gtk_widget_show_all(GNOME_DIALOG(w)->vbox);
-	gtk_widget_show(w);
-}
-/* END OF NOT USED */
-#endif
-
-#if 0
-/* NO LONGER IN USE */
-void gnomecard_add_deladdr(GtkWidget *widget, gpointer data)
-{
-	GnomeCardDelAddr *p;
-	CardDelAddr *addr;
-	char *text[7];
-	int i, flag;
-	
-	p = (GnomeCardDelAddr *) data;
-	
-	flag = 0;
-	for (i = 0; i < 7; i++) {
-		text[i] = gtk_entry_get_text(GTK_ENTRY(p->data[i]));
-		if (*text[i])
-			flag = 1;
-	}
-	
-	if (!flag)
-		return;
-	
-	addr = g_malloc(sizeof(CardDelAddr));
-	
-	for (i = 0; i < DELADDR_MAX; i++)
-		addr->data[i] = MY_STRDUP(text[i]);
-	
-	addr->prop = empty_CardProperty();
-	addr->prop.used = TRUE;
-
-	addr->type = 0;
-	for (i = 0; i < 6; i++)
-		if (GTK_TOGGLE_BUTTON(p->type[i])->active)
-			addr->type |= (int) gtk_object_get_user_data(GTK_OBJECT(p->type[i]));
-	
-	((Card *) p->l->data)->deladdr.l = g_list_append(((Card *) p->l->data)->deladdr.l, addr);
-
-	gnomecard_update_list(p->l->data);
-
-	for (i = 0; i < DELADDR_MAX; i++)
-		gtk_editable_delete_text(GTK_EDITABLE(p->data[i]), 0, strlen(text[i]));
-	gnomecard_set_changed(TRUE);
-}
-
-extern void gnomecard_add_deladdr_call(GtkWidget *widget, gpointer data)
-{
-	GtkWidget *w, *hbox, *frame, *vbox, *table, *label;
-	GnomeCardDelAddr *p;
-	char *title;
-	Card *crd;
-	int i;
-	
-	crd = gnomecard_curr_crd->data;
-	
-	/* + 7 for case crd->fname == 0, which sprintf's to "(null)" */
-	title = g_malloc(strlen(_("Add Delivery Address for ")) + MY_STRLEN(crd->fname.str) + 7);
-	
-	sprintf(title, _("Add Delivery Address for %s"), crd->fname.str);
-	
-	p = g_malloc(sizeof(GnomeCardDelAddr));
-	p->l = gnomecard_curr_crd;
-	w = gnome_dialog_new(title, "Add", GNOME_STOCK_BUTTON_CLOSE, NULL);
-	gtk_object_set_user_data(GTK_OBJECT(w), p);
-	gnome_dialog_button_connect(GNOME_DIALOG(w), 0,
-															GTK_SIGNAL_FUNC(gnomecard_add_deladdr),	p);
-	gnome_dialog_button_connect_object(GNOME_DIALOG(w),	1,
-																		 GTK_SIGNAL_FUNC(gnomecard_cancel),
-																		 GTK_OBJECT(w));
-
-	hbox = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
-	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(w)->vbox), hbox, FALSE, FALSE, 0);
-	
-	frame = gtk_frame_new(_("Address type:"));
-	gtk_box_pack_start(GTK_BOX(hbox), frame, FALSE, FALSE, 0);
-	vbox = gtk_vbox_new(FALSE, GNOME_PAD_SMALL);
-	gtk_container_add(GTK_CONTAINER(frame), vbox);
-
-	for (i = 0; i < 6; i++) {
-		p->type[i] = gtk_check_button_new_with_label(addr_type_name[i]);
-		gtk_object_set_user_data(GTK_OBJECT(p->type[i]), (gpointer) (1 << i));
-		gtk_box_pack_start(GTK_BOX(vbox), p->type[i], FALSE, FALSE, 0);
-	}
-	
-	table = my_gtk_table_new(2, DELADDR_MAX);
-	gtk_box_pack_start(GTK_BOX(hbox), table, FALSE, FALSE, 0);
-	
-	label = gtk_label_new("Post Office:");
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,
-			 GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 0, 0);
-	p->data[0] = gtk_entry_new();
-	gtk_table_attach(GTK_TABLE(table), p->data[0], 1, 2, 0, 1,
-			 GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 0, 0);
-	label = gtk_label_new("Extended:");
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,
-			 GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 0, 0);
-	p->data[1] = gtk_entry_new();
-	gtk_table_attach(GTK_TABLE(table), p->data[1], 1, 2, 1, 2,
-			 GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 0, 0);
-	label = gtk_label_new("Street:");
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 2, 3,
-			 GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 0, 0);
-	p->data[2] = gtk_entry_new();
-	gtk_table_attach(GTK_TABLE(table), p->data[2], 1, 2, 2, 3,
-			 GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 0, 0);
-	label = gtk_label_new("City:");
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 3, 4,
-			 GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 0, 0);
-	p->data[3] = gtk_entry_new();
-	gtk_table_attach(GTK_TABLE(table), p->data[3], 1, 2, 3, 4,
-			 GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 0, 0);
-	label = gtk_label_new("Region:");
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 4, 5,
-			 GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 0, 0);
-	p->data[4] = gtk_entry_new();
-	gtk_table_attach(GTK_TABLE(table), p->data[4], 1, 2, 4, 5,
-			 GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 0, 0);
-	label = gtk_label_new("Code:");
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 5, 6,
-			 GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 0, 0);
-	p->data[5] = gtk_entry_new();
-	gtk_table_attach(GTK_TABLE(table), p->data[5], 1, 2, 5, 6,
-			 GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 0, 0);
-	label = gtk_label_new("Country:");
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 6, 7,
-			 GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 0, 0);
-	p->data[6] = gtk_entry_new();
-	gtk_table_attach(GTK_TABLE(table), p->data[6], 1, 2, 6, 7,
-			 GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 0, 0);
-	
-	gtk_widget_show_all(GNOME_DIALOG(w)->vbox);
-	gtk_widget_show(w);
-}
-
-void gnomecard_add_dellabel(GtkWidget *widget, gpointer data)
-{
-	GnomeCardDelLabel *p;
-	CardDelLabel *addr;
-	char *text;
-	int i;
-	
-	p = (GnomeCardDelLabel *) data;
-	
-	text = gtk_editable_get_chars(GTK_EDITABLE(p->data), 0,
-				      gtk_text_get_length(GTK_TEXT(p->data)));
-	if (*text == 0)
-	  return;
-	
-	addr = g_malloc(sizeof(CardDelLabel));
-	addr->data = MY_STRDUP(text);
-	addr->prop = empty_CardProperty();
-	addr->prop.encod = ENC_QUOTED_PRINTABLE;
-	addr->prop.used = TRUE;
-
-	addr->type = 0;
-	for (i = 0; i < 6; i++)
-	  if (GTK_TOGGLE_BUTTON(p->type[i])->active)
-	    addr->type |= (int) gtk_object_get_user_data(GTK_OBJECT(p->type[i]));
-	
-	((Card *) p->l->data)->dellabel.l = g_list_append(((Card *) p->l->data)->dellabel.l, addr);
-
-	gnomecard_update_list(p->l->data);
-
-	gtk_editable_delete_text(GTK_EDITABLE(p->data), 0, strlen(text));
-	gnomecard_set_changed(TRUE);
-}
-
-extern void gnomecard_add_dellabel_call(GtkWidget *widget, gpointer data)
-{
-}
-#endif
-
-
-
 extern void gnomecard_edit_card(GtkWidget *widget, gpointer data)
 {
     if (gnomecard_curr_crd)
@@ -1578,8 +1205,8 @@ extern void gnomecard_about(GtkWidget *widget, gpointer data)
 				   "drmike@redhat.com",
 				   NULL };
 	
-	about = gnome_about_new (_("gnomecard"), NULL,
-				 "(C) 1997-1998 the Free Software Fundation",
+	about = gnome_about_new (_("GnomeCard"), NULL,
+				 "(C) 1997-1998 the Free Software Foundation",
 				 authors,
 				 _("Electronic Business Card Manager"),
 				 NULL);
@@ -1693,23 +1320,11 @@ static void gnomecard_find_card(GtkWidget *w, gpointer data)
 			found = 1;
 */		
 
-/* NOT USED
 		for (k = crd->deladdr.l; k && !found; k = k->next)
 		    for (i = 0; i < DELADDR_MAX; i++)
 			if (gnomecard_match_pattern(pattern, 
 						    ((CardDelAddr *) k->data)->data[i], sens))
 			    found = 1;
-*/
-		for (k = crd->postal.l; k && !found; k = k->next) {
-		    CardPostAddr *p = ((CardPostAddr *)k->data);
-
-		    found = gnomecard_match_pattern(pattern,p->street1,sens) ||
-			gnomecard_match_pattern(pattern,p->street2,sens) ||
-			gnomecard_match_pattern(pattern,p->city,sens) ||
-			gnomecard_match_pattern(pattern,p->state,sens) ||
-			gnomecard_match_pattern(pattern,p->zip,sens) ||
-			gnomecard_match_pattern(pattern,p->country,sens);
-		}
 		
 		if (found) {
 		    gnomecard_scroll_list(l);
